Awesome stuff built with P2PD
===============================

I've been working earnestly on P2PD for over a year now and the project
has really come along. In that time span I've implemented many protocols
from scratch starting from fundamental principles of how networking
should be handled. The bellow pages list tools that are useful alone.

.. toctree::
    irc_kvs
    stun
    turn
    netifaces
    http_client
    http_framework
    toxiproxy

